===============================
branchesv
===============================

.. image:: https://img.shields.io/pypi/v/branchesv.svg
        :target: https://pypi.python.org/pypi/branchesv

.. image:: https://readthedocs.org/projects/branchesv/badge/?version=latest
        :target: https://branchesv.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://git.vauxoo.com/vauxoo/branchesv/badges/master/build.svg
        :target: https://git.vauxoo.com/vauxoo/branchesv/commits/master
        :alt: Gitlab CI


Python package to get the information of all the repos in a directory

* Free software: GNU General Public License v3
* Documentation: https://branchesv.readthedocs.io.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
